@@ -12,7 +12,11 @@ from fandjango.settings import (
     FACEBOOK_APPLICATION_INITIAL_PERMISSIONS
 )
 
-def authorize_application(request, redirect_uri='https://%s/%s' % (FACEBOOK_APPLICATION_DOMAIN, FACEBOOK_APPLICATION_NAMESPACE)):
+def authorize_application(
+    request,
+    redirect_uri = 'https://%s/%s' % (FACEBOOK_APPLICATION_DOMAIN, FACEBOOK_APPLICATION_NAMESPACE),
+    permissions = FACEBOOK_APPLICATION_INITIAL_PERMISSIONS
+    ):
     """
     Redirect the user to authorize the application.
 
@@ -24,16 +28,16 @@ def authorize_application(request, redirect_uri='https://%s/%s' % (FACEBOOK_APPL
         'redirect_uri': redirect_uri
     }
 
-    if FACEBOOK_APPLICATION_INITIAL_PERMISSIONS:
-        query['scope'] = ', '.join(FACEBOOK_APPLICATION_INITIAL_PERMISSIONS)
+    if permissions:
+        query['scope'] = ', '.join(permissions)
 
     return render(
         request = request,
         template_name = 'fandjango/authorize_application.html',
         dictionary = {
-            'url': 'https://graph.facebook.com/oauth/authorize?%s' % urlencode(query)
+            'url': 'https://www.facebook.com/dialog/oauth?%s' % urlencode(query)
         },
-        status = 303
+        status = 401
     )
 
 def authorization_denied(request):
